import React, { useState, useEffect } from 'react';
import { Input, Menu, Dropdown, Button, Icon, message, Table, Divider, Tag, Select, Form, Alert, Tabs, Row, Col } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import XForm, { FieldTypes } from '../../../components/XForm';
import router from 'umi/router';
import apis from '../../../services/apis';
import request from '../../../utils/request';
import Wangedit from '../../../components/Wangedit/Wangedit'
import moment from 'moment';

const { TabPane } = Tabs;

const header = props => {
    const companyId = props.location.query.id
  
    const [ data, setData ] = useState({})
    if(companyId){
      useEffect(() => {
        getCompanyData(companyId);
      },[])
    
      // 查询列表
      const getCompanyData = (companyId) => {
        request({
            ...apis.company.get,
            urlData: { id: companyId }
        }).then((data) => {
          if(data.certifiedStatus === 'registered'){
            router.push({
              pathname: '/eContract/company/add',
              query: {
                id: companyId
              },
            });
            return
          }
          setData(data)
        }).catch((err) => {
          message.error(err.msg || err.message)
        })
      }
    }else{
      //第一次进入就创建新的企业
      useEffect(() => {
        addCompanyData();
      },[])

      // 添加
      const addCompanyData = () => {
        request({
            ...apis.company.add,
        }).then((data) => {
          setData(data)
        }).catch((err) => {
          message.error(err.msg || err.message)
        })
      }
    }

    const openFddUrl = () => {
      window.open(data.certifiedAddress)
    }

    const getCompanyInfo = () => {
      request({
          ...apis.company.refresh,urlData: { id: data.companyId }
      }).then((data) => {
        setData(data)
      }).catch((err) => {
        message.error(err.msg || err.message)
      })
    }
  
    return (
      <Tabs type="card">
        <TabPane tab="基本信息" key="1">
            <Row>
              <Col span={8}></Col>
              <Col span={4}>企业编号</Col>
              <Col span={4}>{data.companyCode}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>法大大客户编号</Col>
              <Col span={4}>{data.fadadaCode}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>企业管理员身份</Col>
              <Col span={4}>{data.companyManagerType === 'legal' ? '法人' : data.companyManagerType === 'agent' ? "代理人" : "" }</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>认证序列号</Col>
              <Col span={4}>{data.certifiedSerialNumber}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>实名认证地址</Col>
              <Col span={4}><a onClick={openFddUrl}>{data.certifiedAddress}</a></Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>实名认证状态</Col>
              <Col span={4}>{data.status === 0 ? '未认证' : data.status === 1 ? "管理员资料已提交" : data.status === 2 ? "企业基本资料（没有申请表）已提交" : data.status === 3 ? "已提交待审核" : 
                             data.status === 4 ? '审核通过' : data.status === 5 ? "审核不通过" : data.status === 6 ? "人工初审通过" : "" }</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>
                <Button type="danger" onClick={getCompanyInfo}>更新认证状态</Button>
              </Col>
              <Col span={4}>
                <Button type="danger" onClick={() => router.go(-1)}>返回</Button>
              </Col>
              <Col span={8}></Col>
            </Row>
        </TabPane>
        <TabPane tab="企业认证信息" key="2">
        <Row>
              <Col span={8}></Col>
              <Col span={4}>认证状态</Col>
              <Col span={4}>{data.status === 0 ? '未认证' : data.status === 1 ? "管理员资料已提交" : data.status === 2 ? "企业基本资料（没有申请表）已提交" : data.status === 3 ? "已提交待审核" : 
                             data.status === 4 ? '审核通过' : data.status === 5 ? "审核不通过" : data.status === 6 ? "人工初审通过" : "" }</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>不通过原因</Col>
              <Col span={4}>{data.reason}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>审核时间</Col>
              <Col span={4}>{data.verifyTime}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>认证方式</Col>
              <Col span={4}>{data.certifiedType === 0 ? "银行卡认证" : data.certifiedType === 1 ? "纸质审核认证" : ""}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>企业信息</Col>
              <Col span={4}></Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>企业名称</Col>
              <Col span={4}>{data.companyName}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>统一社会信用代码</Col>
              <Col span={4}>{data.creditCode}</Col>
              <Col span={8}></Col>
            </Row>

            <Row>
              <Col span={8}></Col>
              <Col span={4}><span>对公账号信息</span></Col>
              <Col span={4}></Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>银行名称</Col>
              <Col span={4}>{data.bankName}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>银行帐号</Col>
              <Col span={4}>{data.bankAccount}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>开户支行名称</Col>
              <Col span={4}>{data.subbranchName}</Col>
              <Col span={8}></Col>
            </Row>

            <Row>
              <Col span={8}></Col>
              <Col span={4}>企业管理员身份</Col>
              <Col span={4}>{data.companyManagerType === 'legal' ? '法人' : data.companyManagerType === 'agent' ? "代理人" : ""}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>姓名</Col>
              <Col span={4}>{data.userName}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>手机号</Col>
              <Col span={4}>{data.tel}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>身份证号码</Col>
              <Col span={4}>{data.idCard}</Col>
              <Col span={8}></Col>
            </Row>
            <Row>
              <Col span={8}></Col>
              <Col span={4}>
                <Button type="danger" onClick={getCompanyInfo}>更新企业认证信息</Button>
              </Col>
              <Col span={4}>
                <Button type="danger" onClick={() => router.go(-1)}>返回</Button>
              </Col>
              <Col span={8}></Col>
            </Row>
        </TabPane>
      </Tabs> 
    )
  }
  
  const WrappedNormalLoginForm = Form.create({ name: 'header' })(header);
  export default WrappedNormalLoginForm